@@ -1,7 +1,6 @@
 OC.L10N.register(
     "circles",
     {
-    "Teams" : "Команды",
     "You created the team {circle}" : "Вы создали группу {circle}",
     "{author} created the team {circle}" : "{author} создал круг {circle}",
     "You deleted {circle}" : "Вы удалили круг «{circle}»",
@@ -52,6 +51,7 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member} отправил(а) запрос на вступление в «{circle}»",
     "You are the new owner of {circle}" : "Вы стали владельцем «{circle}»",
     "{member} is the new owner of {circle}" : "{member} новый владелец «{circle}»",
+    "Teams" : "Команды",
     "On events happening in a <strong>team</strong> of which you are a member" : "О событиях, происходящих в <strong>группе</strong>, членом которой вы являетесь",
     "Any important event in a <strong>team</strong> you are moderating" : "Любое важное событие в <strong>группе</strong>, которую вы модерируете",
     "On global events happening in any <strong>team</strong>" : "О глобальных событиях, происходящих в любой <strong>группе</strong>",
@@ -106,12 +106,10 @@ OC.L10N.register(
     "Circles App Initialization" : "Инициализация приложения \"Круги\"",
     "Fresh installation status" : "Статус новой установки",
     "Building Local Database" : "Создание локальной базы данных",
-    "Testing Basic Circle Creation" : "Тестирование базового созданного Круга",
     "Adding local users and moderators" : "Добавление локальных пользователей и модераторов",
     "Show all teams" : "Показать все группы",
     "Create a new team" : "Создать новую группу",
     "Files" : "Файлы",
-    "This feature is not available for personal circles" : "Эта возможность недоступна для личных кругов",
     "The team is not federated" : "Не федеративная группа",
     "You cannot join this team" : "Вы не можете вступить в эту группу",
     "This member is not a moderator" : "Это участник — не модератор",
@@ -119,10 +117,6 @@ OC.L10N.register(
     "This member does not exist" : "Этот участник не существует",
     "This member is the owner of the team" : "Этот участник является владельцем группы",
     "Level cannot be changed for this type of member" : "Невозможно изменить уровень участника такого типа",
-    "You are already a member of this circle" : "Вы уже участник этого круга",
-    "You have been blocked from this circle" : "Вы заблокированы от участия в этом круге",
-    "The account is already a member of this circle" : "Эта учётная запись уже участник этого круга",
-    "The account has already been invited into this circle" : "Эта учётная запись уже приглашена в этот круг",
     "%s (Team owned by %s)" : "%s (Группа принадлежит %s)",
     "You are now a member of the Team \"%2$s\"" : "Вы теперь участник Группы \"%2$s\"",
     "You have been invited by %1$s into the Team \"%2$s\"" : "Вы были приглашены %1$s s в Группу \"%2$s\"",
@@ -158,11 +152,6 @@ OC.L10N.register(
     "Name" : "Имя",
     "Size" : "Размер",
     "Modified" : "Изменён",
-    "Teams' files" : "Файлы групп",
-    "Select team to filter by" : "Выберите группу для фильтрации по",
-    "Please select teams to filter by" : "Пожалуйста, выберите группы для фильтрации по",
-    "No files found for the selected teams" : "Для выбранных групп файлы не найдены",
-    "Shared to Circles" : "Предоставленный кругам общий доступ",
-    "Circle" : "Круг"
+    "Shared to Circles" : "Предоставленный кругам общий доступ"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
