@@ -4,28 +4,8 @@ declare(strict_types=1);
 
 
 /**
- * Circles - Bring cloud-users closer together.
- *
- * This file is licensed under the Affero General Public License version 3 or
- * later. See the COPYING file.
- *
- * @author Maxence Lange <maxence@artificial-owl.com>
- * @copyright 2021
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 
@@ -104,6 +84,7 @@ class ShareWrapperRequest extends ShareWrapperRequestBuilder {
 			->set('uid_initiator', $qb->createNamedParameter($shareWrapper->getSharedBy()))
 			->set('accepted', $qb->createNamedParameter(IShare::STATUS_ACCEPTED))
 			->set('permissions', $qb->createNamedParameter($shareWrapper->getPermissions()))
+			->set('note', $qb->createNamedParameter($shareWrapper->getShareNote()))
 			->set('expiration', $qb->createNamedParameter($shareWrapper->getExpirationDate(), IQueryBuilder::PARAM_DATE))
 			->set('attributes', $qb->createNamedParameter($shareAttributes));
 
@@ -112,6 +93,22 @@ class ShareWrapperRequest extends ShareWrapperRequestBuilder {
 		$qb->execute();
 	}
 
+	/**
+	 * update permissions and attributes from child
+	 */
+	public function updateChildPermissions(ShareWrapper $shareWrapper): void {
+		$qb = $this->getShareUpdateSql();
+		$shareAttributes = $this->formatShareAttributes($shareWrapper->getAttributes());
+
+		$qb->set('permissions', $qb->createNamedParameter($shareWrapper->getPermissions()))
+			->set('attributes', $qb->createNamedParameter($shareAttributes));
+
+		$qb->limitToShareParent((int)$shareWrapper->getId());
+		$qb->gt('permissions', 0);
+
+		$qb->execute();
+	}
+
 
 	/**
 	 * @param Membership $membership
@@ -148,7 +145,7 @@ class ShareWrapperRequest extends ShareWrapperRequestBuilder {
 		string $circleId,
 		?FederatedUser $shareRecipient = null,
 		?FederatedUser $shareInitiator = null,
-		bool $completeDetails = false
+		bool $completeDetails = false,
 	): array {
 		$qb = $this->getShareSelectSql();
 		$qb->limitNull('parent', false);
@@ -182,6 +179,24 @@ class ShareWrapperRequest extends ShareWrapperRequestBuilder {
 	}
 
 
+	/**
+	 * @param string $circleId
+	 * @param FederatedUser|null $shareRecipient
+	 * @param FederatedUser|null $shareInitiator
+	 * @param bool $completeDetails
+	 *
+	 * @return ShareWrapper[]
+	 * @throws RequestBuilderException
+	 */
+	public function getSharesToCircles(array $circleIds): array {
+		$qb = $this->getShareSelectSql();
+		$qb->limitNull('parent', false);
+		$qb->expr()->in('share_with', $qb->createNamedParameter($circleIds, IQueryBuilder::PARAM_STR_ARRAY));
+		return $this->getItemsFromRequest($qb);
+	}
+
+
+
 	/**
 	 * @param int $shareId
 	 * @param FederatedUser|null $federatedUser
@@ -313,7 +328,7 @@ class ShareWrapperRequest extends ShareWrapperRequestBuilder {
 	public function getSharedWith(
 		FederatedUser $federatedUser,
 		int $nodeId,
-		CircleProbe $probe
+		CircleProbe $probe,
 	): array {
 		$qb = $this->getShareSelectSql();
 		$qb->setOptions(
@@ -362,7 +377,7 @@ class ShareWrapperRequest extends ShareWrapperRequestBuilder {
 		int $limit,
 		int $offset,
 		bool $getData = false,
-		bool $completeDetails = false
+		bool $completeDetails = false,
 	): array {
 		$qb = $this->getShareSelectSql();
 		$qb->setOptions([CoreQueryBuilder::SHARE], ['getData' => $getData]);
@@ -401,7 +416,7 @@ class ShareWrapperRequest extends ShareWrapperRequestBuilder {
 		FederatedUser $federatedUser,
 		Folder $node,
 		bool $reshares,
-		bool $shallow = true
+		bool $shallow = true,
 	): array {
 		$qb = $this->getShareSelectSql();
 
@@ -535,7 +550,7 @@ class ShareWrapperRequest extends ShareWrapperRequestBuilder {
 			$compressedAttributes[] = [
 				$attribute['scope'],
 				$attribute['key'],
-				$attribute['value'] ?? $attribute['enabled']
+				$attribute['value']
 			];
 		}
 
