@@ -10,6 +10,7 @@ use DateTimeZone;
 use OCA\DAV\CalDAV\CalDavBackend;
 use OCA\DAV\CalDAV\Calendar;
 use OCA\DAV\CalDAV\CalendarHome;
+use OCA\DAV\CalDAV\CalendarObject;
 use OCA\DAV\CalDAV\DefaultCalendarValidator;
 use OCA\DAV\CalDAV\TipBroker;
 use OCP\IConfig;
@@ -41,11 +42,6 @@ use function Sabre\Uri\split;
 
 class Plugin extends \Sabre\CalDAV\Schedule\Plugin {
 
-	/**
-	 * @var IConfig
-	 */
-	private $config;
-
 	/** @var ITip\Message[] */
 	private $schedulingResponses = [];
 
@@ -54,16 +50,15 @@ class Plugin extends \Sabre\CalDAV\Schedule\Plugin {
 
 	public const CALENDAR_USER_TYPE = '{' . self::NS_CALDAV . '}calendar-user-type';
 	public const SCHEDULE_DEFAULT_CALENDAR_URL = '{' . Plugin::NS_CALDAV . '}schedule-default-calendar-URL';
-	private LoggerInterface $logger;
-	private DefaultCalendarValidator $defaultCalendarValidator;
 
 	/**
 	 * @param IConfig $config
 	 */
-	public function __construct(IConfig $config, LoggerInterface $logger, DefaultCalendarValidator $defaultCalendarValidator) {
-		$this->config = $config;
-		$this->logger = $logger;
-		$this->defaultCalendarValidator = $defaultCalendarValidator;
+	public function __construct(
+		private IConfig $config,
+		private LoggerInterface $logger,
+		private DefaultCalendarValidator $defaultCalendarValidator,
+	) {
 	}
 
 	/**
@@ -137,7 +132,7 @@ class Plugin extends \Sabre\CalDAV\Schedule\Plugin {
 	 * @param string $principal
 	 * @return array
 	 */
-	protected function getAddressesForPrincipal($principal) {
+	public function getAddressesForPrincipal($principal) {
 		$result = parent::getAddressesForPrincipal($principal);
 
 		if ($result === null) {
@@ -176,8 +171,8 @@ class Plugin extends \Sabre\CalDAV\Schedule\Plugin {
 			if (!$this->scheduleReply($this->server->httpRequest)) {
 				return;
 			}
-			
-			/** @var \OCA\DAV\CalDAV\Calendar $calendarNode */
+
+			/** @var Calendar $calendarNode */
 			$calendarNode = $this->server->tree->getNodeForPath($calendarPath);
 			// extract addresses for owner
 			$addresses = $this->getAddressesForPrincipal($calendarNode->getOwner());
@@ -192,7 +187,7 @@ class Plugin extends \Sabre\CalDAV\Schedule\Plugin {
 			// determine if we are updating a calendar event
 			if (!$isNew) {
 				// retrieve current calendar event node
-				/** @var \OCA\DAV\CalDAV\CalendarObject $currentNode */
+				/** @var CalendarObject $currentNode */
 				$currentNode = $this->server->tree->getNodeForPath($request->getPath());
 				// convert calendar event string data to VCalendar object
 				/** @var \Sabre\VObject\Component\VCalendar $currentObject */
@@ -583,7 +578,7 @@ EOF;
 		$calendarTimeZone = new DateTimeZone('UTC');
 
 		$homePath = $result[0][200]['{' . self::NS_CALDAV . '}calendar-home-set']->getHref();
-		/** @var \OCA\DAV\CalDAV\Calendar $node */
+		/** @var Calendar $node */
 		foreach ($this->server->tree->getNodeForPath($homePath)->getChildren() as $node) {
 
 			if (!$node instanceof ICalendar) {
