@@ -23,45 +23,54 @@ OC.L10N.register(
     "Sharing" : "Condivisione",
     "Federated file sharing" : "Condivisione file federata",
     "Provide federated file sharing across servers" : "Fornisce una condivisione di file federata tra server",
+    "Confirm data upload to lookup server" : "Conferma il caricamento dei dati sul server di ricerca",
+    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "Se abilitata, tutte le proprietà dell'account (ad esempio l'indirizzo e-mail) con visibilità dell'ambito impostata su \"pubblicato\" verranno automaticamente sincronizzate e trasmesse a un sistema esterno e rese disponibili in una rubrica pubblica globale.",
+    "Disable upload" : "Disattiva il caricamento",
+    "Enable data upload" : "Abilita il caricamento dei dati",
+    "Confirm querying lookup server" : "Conferma richiesta al server di ricerca",
+    "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "Se abilitata, l'input di ricerca durante la creazione delle condivisioni verrà inviato a un sistema esterno che fornisce una rubrica pubblica e globale.",
+    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "Serve a recuperare l'ID cloud federato per semplificare la condivisione federata.",
+    "Moreover, email addresses of users might be sent to that system in order to verify them." : "Inoltre, gli indirizzi email degli utenti potrebbero essere inviati a tale sistema per verificarli.",
+    "Disable querying" : "Disabilita le query",
+    "Enable querying" : "Abilita query",
+    "Unable to update federated files sharing config" : "Impossibile aggiornare la configurazione della condivisione federata dei file",
     "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Regola come le persone possono condividere tra i server. Ciò include anche le condivisioni tra persone in questo server se usano la condivisione federata.",
     "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Consenti alle persone su questo server di inviare condivisioni ad altri server (questa opzione consente anche l'accesso WebDAV alle condivisioni pubbliche)",
     "Allow people on this server to receive shares from other servers" : "Consenti alle persone su questo server di ricevere condivisioni da altri server",
     "Allow people on this server to send shares to groups on other servers" : "Consenti alle persone su questo server di inviare condivisioni a gruppi su altri server",
     "Allow people on this server to receive group shares from other servers" : "Consenti alle persone su questo server di ricevere condivisioni di gruppo da altri server",
+    "The lookup server is only available for global scale." : "Il server di ricerca è disponibile solo su scala globale.",
     "Search global and public address book for people" : "Cerca persone nella rubrica globale e pubblica",
     "Allow people to publish their data to a global and public address book" : "Consenti alle persone di pubblicare i propri dati in una rubrica globale e pubblica",
-    "Unable to update federated files sharing config" : "Impossibile aggiornare la configurazione della condivisione federata dei file",
+    "Trusted federation" : "Federazioni attendibili",
+    "Automatically accept shares from trusted federated accounts and groups by default" : "Accetta automaticamente le condivisioni da account e gruppi federati attendibili",
+    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Condividi con me attraverso il mio ID di cloud federato #Nextcloud, vedi {url}",
+    "Share with me through my #Nextcloud Federated Cloud ID" : "Condividi con me attraverso il mio ID di cloud federata #Nextcloud",
+    "Share with me via Nextcloud" : "Condividi con me tramite Nextcloud",
+    "Cloud ID copied" : "ID cloud copiato",
+    "Copy" : "Copia",
+    "Clipboard not available. Please copy the cloud ID manually." : "Appunti non disponibili. Copia manualmente l'ID cloud.",
+    "Copied!" : "Copiato!",
     "Federated Cloud" : "Cloud federata",
-    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Puoi condividere con chiunque utilizzi server Nextcloud o altri server e servizi Open Cloud Mesh (OCM) compatibili. Ti basta inserire il loro ID di cloud federata nella finestra di condivisione. Assomiglia a persona@cloud.esempio.com ",
+    "You can share with anyone who uses a {productName} server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Puoi condividere con chiunque utilizzi un server {productName} o altri server e servizi compatibili con Open Cloud Mesh (OCM)! Basta inserire il loro Federated Cloud ID nella finestra di dialogo di condivisione. Ha questo aspetto: person@cloud.example.com",
+    "Your Federated Cloud ID" : "Il tuo ID cloud federato",
     "Share it so your friends can share files with you:" : "Condividilo in modo che i tuoi amici possano condividere file con te:",
     "Facebook" : "Facebook",
     "X (formerly Twitter)" : "X (ex Twitter)",
+    "formerly Twitter" : "precedentemente Twitter",
     "Mastodon" : "Mastodon",
+    "Bluesky" : "Bluesky",
     "Add to your website" : "Aggiungi al tuo sito web",
-    "Share with me via Nextcloud" : "Condividi con me tramite Nextcloud",
+    "Share with me via {productName}" : "Condividi con me tramite {productName}",
     "HTML Code:" : "Codice HTML:",
-    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Condividi con me attraverso il mio ID di cloud federato #Nextcloud, vedi {url}",
-    "Share with me through my #Nextcloud Federated Cloud ID" : "Condividi con me attraverso il mio ID di cloud federata #Nextcloud",
-    "Cloud ID copied to the clipboard" : "ID di cloud copiato negli appunti",
-    "Copy to clipboard" : "Copia negli appunti",
-    "Copied!" : "Copiato!",
     "Cancel" : "Annulla",
     "Add remote share" : "Aggiungi condivisione remota",
     "Remote share" : "Condivisione remota",
     "Do you want to add the remote share {name} from {owner}@{remote}?" : "Vuoi aggiungere la condivisione remota {name} da {owner}@{remote}?",
     "Remote share password" : "Password della condivisione remota",
-    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Condivisione di %1$s non riuscita, poiché l'elemento è già condiviso con l'utente %2$s",
-    "Not allowed to create a federated share with the same user" : "Non è consentito creare una condivisione federata con lo stesso utente",
-    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Regola come le persone possono condividere tra i server. Ciò include anche le condivisioni tra utenti in questo server se usano la condivisione federata.",
-    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Consenti agli utenti su questo server di inviare condivisioni ad altri server (questa opzione consente anche l'accesso WebDAV alle condivisioni pubbliche)",
-    "Allow users on this server to receive shares from other servers" : "Consenti agli utenti su questo server di ricevere condivisioni da altri server",
-    "Allow users on this server to send shares to groups on other servers" : "Consenti agli utenti su questo server di inviare condivisioni a gruppi su altri server",
-    "Allow users on this server to receive group shares from other servers" : "Consenti agli utenti su questo server di ricevere condivisioni di gruppo da altri server",
-    "Search global and public address book for users" : "Cerca gli utenti nella rubrica globale e pubblica",
-    "Allow users to publish their data to a global and public address book" : "Consenti agli utenti di pubblicare i propri dati in una rubrica globale e pubblica",
-    "Your Federated Cloud ID:" : "Il tuo ID di cloud federata:",
-    "Twitter" : "Twitter",
-    "Diaspora" : "Diaspora",
-    "Clipboard is not available" : "Appunti non disponibili"
+    "Incoming share could not be processed" : "Non è stato possibile elaborare la condivisione in entrata",
+    "Cloud ID copied to the clipboard" : "ID di cloud copiato negli appunti",
+    "Copy to clipboard" : "Copia negli appunti",
+    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Puoi condividere con chiunque utilizzi server Nextcloud o altri server e servizi Open Cloud Mesh (OCM) compatibili. Ti basta inserire il loro ID di cloud federata nella finestra di condivisione. Assomiglia a persona@cloud.esempio.com "
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
