@@ -21,6 +21,9 @@ OC.L10N.register(
     "Mark selection as favorite" : "Marcar seleção como favorito",
     "Add selection to favorites" : "Adicionar seleção aos favoritos",
     "Remove selection from favorites" : "Remover seleção dos favoritos",
+    "This name is already in use." : "Este nome já está em uso.",
+    "\"{char}\" is not allowed inside a filename." : "\"{char}\" não é permitido dentro de um nome de arquivo.",
+    "Invalid filename." : "Nome de arquivo inválido.",
     "Name of the album" : "Nome do álbum",
     "Location of the album" : "Localização do álbum",
     "Back" : "Voltar",
@@ -69,22 +72,19 @@ OC.L10N.register(
     "The destination folder is owned by {owner}" : "A pasta de destino pertence a {owner}",
     "There are no photos or videos yet!" : "Ainda não há fotos ou vídeos!",
     "_{years} year ago_::_{years} years ago_" : ["há {years} ano","há {years} anos","há {years} anos"],
-    "Enable squared photos view" : "Ativar exibição de fotos quadradas",
+    "Squared photos view" : "Visualização de fotos quadradas",
     "Delete source directory" : "Excluir diretório de origem",
     "Pick folder" : "Selecionar pasta",
     "Select a source folder for your media" : "Selecione uma pasta de origem para sua mídia",
+    "Media folders" : "Pastas de mídia",
+    "Choose the folders from where photos and videos are shown." : "Escolha as pastas de onde as fotos e os vídeos são exibidos.",
     "All folders" : "Todas as pastas",
     "Add a Photos source for the timelines" : "Adicione uma fonte de Fotos para as linhas do tempo",
     "Add folder" : "Adicionar pasta",
-    "Select the default upload location for your media" : "Selecione o local de upload padrão para sua mídia",
     "Home" : "Início",
-    "Choose default Photos upload and Albums location" : "Escolha o local padrão para upload de Fotos e Álbuns",
-    "Choose a different folder" : "Escolha uma pasta diferente",
-    "View" : "Exibição",
-    "Media folders" : "Pastas de mídia",
-    "Choose the folders from where photos and videos are shown." : "Escolha as pastas de onde as fotos e os vídeos são exibidos.",
+    "Select the default upload location for your media" : "Selecione o local de upload padrão para sua mídia",
     "Upload folder" : "Pasta para uploads",
-    "Choose the folder where photos and albums are uploaded to." : "Escolha a pasta na qual as fotos e os álbuns serão carregados.",
+    "General" : "Geral",
     "_%n photo_::_%n photos_" : ["%n foto","%n fotos","%n fotos"],
     "Unselect all" : "Desmarcar todos",
     "Add photos to this album" : "Adicionar fotos a este álbum",
@@ -158,7 +158,12 @@ OC.L10N.register(
     "Failed to create {collectionFileName}" : "Falha ao criar {collectionFileName}",
     "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "Falha ao renomear {currentCollectionFileName} para {newCollectionFileName}",
     "Failed to update properties of {collectionFileName} with {properties}" : "Falha ao atualizar as propriedades de {collectionFileName} com {properties}",
+    "Delete collection" : "Excluir coleção",
+    "Leave shared album" : "Deixe o álbum compartilhado",
+    "Are you sure you want to delete {collectionName}? This action cannot be undone." : "Tem certeza de que deseja excluir {collectionName}? Esta ação não pode ser desfeita.",
     "Failed to delete {collectionFileName}" : "Falha ao excluir {collectionFileName}",
+    "Cancel" : "Cancelar",
+    "Confirm" : "Confirmar",
     "Failed to move {fileBaseName} to person {faceName}" : "Falha ao mover {fileBaseName} à pessoa {faceName}",
     "Failed to remove {fileBaseName}" : "Falha ao remover {fileBaseName}",
     "Failed to rename {oldName} to {faceName}" : "Falha ao renomear {oldName} para {faceName}",
@@ -172,8 +177,12 @@ OC.L10N.register(
     "Remove {collaboratorLabel} from the collaborators list" : "Remover {collaboratorLabel} da lista de colaboradores",
     "Back to {folder}" : "Voltar para {folder}",
     "Share this folder" : "Compartilhar esta pasta",
+    "Enable squared photos view" : "Ativar exibição de fotos quadradas",
+    "Choose default Photos upload and Albums location" : "Escolha o local padrão para upload de Fotos e Álbuns",
+    "Choose a different folder" : "Escolha uma pasta diferente",
+    "View" : "Exibição",
+    "Choose the folder where photos and albums are uploaded to." : "Escolha a pasta na qual as fotos e os álbuns serão carregados.",
     "Loading folders …" : "Carregando pastas …",
-    "One of the source folders does not exists" : "Uma das pastas de origem não existe",
     "Add" : "Adicionar"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
