@@ -22,15 +22,6 @@ OC.L10N.register(
     "Text" : "文本 ",
     "📝 Collaborative document editing" : "文档协作编辑",
     "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "** 📝 协作式的文档编辑！**\n\n- **📝 专注的写作：** 无干扰，只有您需要的格式化。\n- **🙋 一起工作：** 与朋友和同事共享协作，无论他们是否使用Nextcloud！\n- **💾 开放标准：** 文件将保存为 [Markdown](https://en.wikipedia.org/wiki/Markdown)，所以您也可以使用任何其他文本应用。\n- **✊ 雄厚基础：** 我们使用 [🐈 tiptap](https://tiptap.scrumpy.io) ，它基于 [🦉 ProseMirror](https://prosemirror.net) – 非常感谢它们！",
-    "Insert result" : "插入结果",
-    "Nextcloud Assistant result copied" : "已复制 Nextcloud 助手结果",
-    "Could not copy result to clipboard" : "无法复制结果至剪切板",
-    "Nextcloud Assistant" : "Nextcloud助手",
-    "Translate" : "翻译",
-    "Show assistant results" : "显示助手结果",
-    "Assistant results" : "助手结果",
-    "Show result" : "显示结果",
-    "Delete task" : "删除任务",
     "Overwrite the file and save the current changes" : "覆盖文件并保存当前更改",
     "Discard the current changes and load the latest version" : "放弃当前更改并加载最新版本",
     "Reload" : "重载",
@@ -41,13 +32,15 @@ OC.L10N.register(
     "This file is opened read-only as it is currently locked by {user}." : "该文件以仅读模式打开，其正被用户 {user} 锁定。",
     "Close outline view" : "关闭大纲视图",
     "Outline" : "大纲",
+    "Insert below" : "下方插入",
+    "Click for options, hold to drag" : "点击以查看选项，按住可拖动",
     "Not connected. Cannot update guest name." : "未连接。无法更新访客名称。",
     "Failed to update the guest name." : "无法更新访客名称。",
     "Enter your name so other people can see who is editing" : "输入你的名称来让其他用户可以看到是谁在编辑。",
     "Enter your name" : "输入名称",
     "Guest" : "访客",
     "submit" : "提交",
-    "you" : "你",
+    "you" : "您",
     "edit" : "编辑",
     "Uploading multiple attachments failed." : "上传多个附件失败。",
     "Uploading attachment failed: {error}" : "上传附件失败：{error}",
@@ -126,6 +119,10 @@ OC.L10N.register(
     "Save changes" : "保存更改",
     "Cancel" : "取消",
     "URL" : "URL",
+    "Edit block formula" : "编辑块公式",
+    "Edit inline formula" : "编辑行内公式",
+    "LaTeX formula" : "LaTeX 公式",
+    "Save" : "保存",
     "Disabled because you are currently offline." : "已禁用，因为您当前已离线。",
     "Attachments cannot be created or uploaded because this file is shared from another cloud." : "无法创建或上传附件，因为此文件是从另一个云共享的。",
     "Upload from computer" : "从电脑上传",
@@ -136,6 +133,15 @@ OC.L10N.register(
     "Update link" : "更新链接",
     "Open the Smart Picker" : "打开智能选择器",
     "{menuItemName}, \"{selectedSubMenuItemName}\" is selected" : "{menuItemName}, \"{selectedSubMenuItemName}\" 已选择",
+    "Insert result" : "插入结果",
+    "Nextcloud Assistant result copied" : "已复制 Nextcloud 助手结果",
+    "Could not copy result to clipboard" : "无法复制结果至剪切板",
+    "Translate" : "翻译",
+    "Show assistant results" : "显示助手结果",
+    "Assistant results" : "助手结果",
+    "Nextcloud Assistant" : "Nextcloud助手",
+    "Show result" : "显示结果",
+    "Delete task" : "删除任务",
     "_%n word_::_%n words_" : ["%n 字"],
     "_%n char_::_%n chars_" : ["%n 字符"],
     "Remaining actions" : "重命名操作",
@@ -201,6 +207,8 @@ OC.L10N.register(
     "Increase indentation" : "增加缩进",
     "Decrease indentation" : "减少缩进",
     "Blocks" : "区块",
+    "Inline math" : "行内数学",
+    "Block math" : "块数学",
     "Info callout" : "信息标注",
     "Success callout" : "成功标注",
     "Warning callout" : "警告标注",
