@@ -93,6 +93,7 @@ OC.L10N.register(
     "Destination does not exist" : "المَقصِد غير موجود",
     "Destination is not creatable" : "المِقصِد لايمكن إنشاؤه",
     "Dot files are not allowed" : "الملفات النقطية (ملفات ذات أسماء تبدأ بنقطة) غير مسموح بها",
+    "renamed file" : "ملف معاد تسميته",
     "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" غير مسموح به أن يكون اسم ملف أو مجلد.",
     "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" غير مسموح به أن يكون بادئة لاسم ملف أو مجلد.",
     "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" غير مسموح به أن يكون داخل اسم ملف أو مجلد.",
@@ -142,7 +143,7 @@ OC.L10N.register(
     "About" : "عن",
     "Display name" : "اسم العرض",
     "Headline" : "عنوان ",
-    "Organisation" : "مؤسسة",
+    "Organization" : "المنظمة",
     "Role" : "الوظيفة",
     "Pronouns" : "الضمائر",
     "Unknown account" : "حساب غير معروف",
@@ -156,7 +157,6 @@ OC.L10N.register(
     "Oracle connection could not be established" : "لم تنجح محاولة اتصال Oracle",
     "Oracle Login and/or password not valid" : "مُعرف تسجيل الدخول او كلمة مرور Oracle غير صحيحة",
     "PostgreSQL Login and/or password not valid" : "مُعرف تسجيل دخول او كلمة مرور PostgreSQL غير صحيحة",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "\"Mac OS X\" غير مدعوم؛ و %s سوف لن يعمل بالشكل الصحيح على هذه المنصة. استعمله على مسؤوليتك!",
     "For the best results, please consider using a GNU/Linux server instead." : "فضلاً ضع في الاعتبار استخدام نظام GNU/Linux بدل الأنظمة الأخرى للحصول على أفضل النتائج.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "يبدو أن كائن %s يعمل على بيئة PHP 32-Bit  وكذلك تم تكوين open_basedir في ملف php.ini. يؤدي ذلك إلى مشاكل مع الملفات التي يزيد حجمها عن 4 غيغابايت ولا يُنصح بذلك بشدة.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "فضلاً إحذف إعداد open_basedir من ملف php.ini لديك أو حوّل إلى PHP إصدار 64 بت.",
@@ -284,8 +284,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "تعذّرت الكتابة في الدليل 'config\".",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "يمكن إصلاح هذا عادةً بمنح خادم الويب صلاحية الوصول إلى الدليل \"config\". للمزيد، أنظر: %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "و إذا كنت تُفضّل بقاء الملف \"config.php\" للقراءة فقط، عيّن الخيار  \"config_is_read_only\". أنظر: %s",
-    "Cannot write into \"apps\" directory." : "لا يمكن الكتابة في الدليل \"apps\".",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "يمكن إصلاح ذلك عادةً عن طريق منح خادم الويب حق الكتابة في دليل التطبيقات في الملف او تعطيل متجر تطبيقات ابل في ملف \"config\".",
     "Cannot create \"data\" directory." : "لا يمكن إنشاء ملف بيانات",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "يمكن إصلاح ذلك عادةً عن طريق منح خادم الويب حق الكتابة في الدليل الجذري root directory.  أنطر:%s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "الصلاحيات يمكن إصلاحها عادةً عن طريق منح خادم الويب حق الكتابة في الدليل الجذري root directory. أنظر:%s.",
@@ -296,8 +294,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "يرجى مطالبة مسؤول الخادم بتثبيت الوحدة.",
     "PHP setting \"%s\" is not set to \"%s\"." : "إعداد PHP  \"%s\" لم يتم تعيينه إلى \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "تضبيط الإعدادات في ملف php.ini سوف يُمكّن نيكست كلاود من العمل مجدداً",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> تمّ تعيينه إلى <code>%s</code> بدلاً عن القيمة المتوقعة <code>0</code>.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "لإصلاح هذا الخطأ، قم بتعيين<code>mbstring.func_overload</code> إلى <code>0</code> في php.ini.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "يبدو أنه تم إعداد PHP لتجريد كتل المستندات المضمنة. سيؤدي ذلك إلى جعل العديد من التطبيقات الأساسية غير قابلة للوصول.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "ربما يكون السبب في ذلك هو ذاكرة التخزين المؤقت/المسرع مثل Zend OPcache أو eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "تم تثبيت وحدات PHP ، لكنها لا تزال مدرجة على أنها وحدات مفقودة؟",
@@ -322,26 +318,30 @@ OC.L10N.register(
     "Storage is temporarily not available" : "وحدة التخزين غير متوفرة",
     "Storage connection timeout. %s" : "انتهت مهلة الاتصال بالتخزين. %s",
     "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "للسماح بتشغيل هذا الفحص، عليك التأكد من أن خادم الويب الخاص بك يمكنه الاتصال بنفسه. لذلك، يجب أن يكون قادراً على حل المشكلة والاتصال بواحد على الأقل من \"النطاقات_الموثوقة\" أو \"overwrite.cli.url\". قد يكون هذا الفشل نتيجة لعدم تطابق DNS من جانب الخادم أو قاعدة صادرة لجدار الحماية.",
+    "Images" : "الصِّوَر",
+    "Question" : "سؤال",
+    "Generated response" : "الاستجابة الناتجة",
+    "System prompt" : "مَحَثُّ النظام",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "تعريف القواعد و الافتراضات التي يجب على المساعد اتِّباعها خلال المحادثة.",
+    "Chat history" : "تاريخ الدردشة",
     "Transcribe audio" : "تحويل الكلام لنص",
     "Transcribe the things said in an audio" : "تحويل الكلام المحكي في المقطع الصوتي إلى نص",
     "Audio input" : "المدخلات الصوتية",
     "The audio to transcribe" : "الكلام المطلوب تحويله إلى نص",
     "Transcription" : "تحويل الكلام لنص",
     "The transcribed text" : "النص المُولّد من الكلام",
-    "ContextAgent" : "وكيل السياق ContextAgent",
-    "Chat with an agent" : "الدردشة مع وكيل",
-    "Chat message" : "رسالة دردشة",
-    "A chat message to send to the agent." : "رسالة دردشة لتُرسل إلى الوكيل.",
     "Confirmation" : "تأكيد",
     "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "ما إذا كان سيتم تأكيد الإجراءات المطلوبة مسبقًا: 0 للرفض و 1 للتأكيد.",
     "Conversation token" : "أَمَارَة المحادثة",
     "A token representing the conversation." : "أَمَارَة تُمثّل المحادثة",
-    "Generated response" : "الاستجابة الناتجة",
-    "The response from the chat model." : "الجواب من نموذج المحادثة.",
     "The new conversation token" : "أَمَارَة المحادثة الجديدة",
     "Send this along with the next interaction." : "أرسل هذا مع التفاعل القادم.",
     "Requested actions by the agent" : "إجراءات يطلبها الوكيل",
     "Actions that the agent would like to carry out in JSON format." : "الإجراءات التي يرغب العميل في تنفيذها بتنسيق JSON.",
+    "Chat with an agent" : "الدردشة مع وكيل",
+    "Chat message" : "رسالة دردشة",
+    "A chat message to send to the agent." : "رسالة دردشة لتُرسل إلى الوكيل.",
+    "The response from the chat model." : "الجواب من نموذج المحادثة.",
     "Context write" : "كتابة السياق",
     "Writes text in a given style based on the provided source material." : "يكتُب النص أسلوب معين بناءً على المادة المصدرية المتوفرة",
     "Writing style" : "أسلُوب الكتابة",
@@ -355,6 +355,7 @@ OC.L10N.register(
     "The text to generate an emoji for" : "نص لتوليد إيموجي عن",
     "Generated emoji" : "الإيموجي المُولَّد",
     "The generated emoji based on the input text" : "الإيموجي المُولَّد بناءً على النص المُدخَل",
+    "Optical character recognition" : "التعرُّف الضوئي على الحروف",
     "Generate image" : "توليد صورة",
     "Generate an image from a text prompt" : "توليد إيموجي من طلب نصّي",
     "Prompt" : "المُطالبة prompt",
@@ -376,9 +377,6 @@ OC.L10N.register(
     "The rewritten text in the desired tone, written by the assistant:" : "النص المعاد صياغته من قِبَل \"المساعد\" بحسب النغمة المطلوبة:",
     "Chat" : "دردشة",
     "Chat with the assistant" : "دردشة مع المُساعِد",
-    "System prompt" : "مَحَثُّ النظام",
-    "Define rules and assumptions that the assistant should follow during the conversation." : "تعريف القواعد و الافتراضات التي يجب على المساعد اتِّباعها خلال المحادثة.",
-    "Chat history" : "تاريخ الدردشة",
     "The history of chat messages before the current message, starting with a message by the user" : "تاريخ رسائل الدردشة ما قبل الرسالة الحالية بدءاً برسالة من المستخدِم",
     "Response message" : "رسالة الرّدّ",
     "The generated response as part of the conversation" : "الرَّدّ المُولّد كجزء من المحادثة",
@@ -442,21 +440,11 @@ OC.L10N.register(
     "Generate headline" : "توليد العنوان",
     "Summarizes text by reducing its length without losing key information." : "يُلَخِّص النص بتقليل طوله دون فقدان المعنى.",
     "Extracts topics from a text and outputs them separated by commas." : "يستخلص المواضيع من النص و إخراجها مفصولة بفواصل.",
-    "Education Edition" : "الإصدار التعليمي",
-    "File name is a reserved word" : "اسم الملف كلمة محجوزة",
-    "File name contains at least one invalid character" : "اسم الملف به ، على الأقل ، حرف غير صالح",
-    "File name is too long" : "اسم الملف طويل جداً",
-    "Users" : "المستخدمين",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s شارك »%2$s« معك و يرغب في إضافة:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s شارك »%2$s« معك و يرغب في إضافة",
-    "»%s« added a note to a file shared with you" : "»%s« أضاف ملاحظة لملفٍ سلفت مشاركته معك",
-    "Open »%s«" : "فتح »%s«",
-    "%1$s shared »%2$s« with you" : "%1$s شارك »%2$s« معك",
-    "%1$s shared »%2$s« with you." : "%1$s شَارَكَ »%2$s« معك.",
-    "Click the button below to open it." : "اضغط على الزر الذي تحته ليتم فتحه.",
-    "File is currently busy, please try again later" : "إنّ الملف مشغول الآمن، يرجى إعادة المحاولة لاحقًا",
-    "Cannot download file" : "لا يمكن تنزيل الملف",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "تأكد من وجود ملفٍ باسم \".ocdata\" في جذر دليل البيانات data directory.",
-    "Path contains files shared with you" : "يحتوي المسار على ملفات تمّت مشاركتها معك"
+    "Organisation" : "مؤسسة",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "\"Mac OS X\" غير مدعوم؛ و %s سوف لن يعمل بالشكل الصحيح على هذه المنصة. استعمله على مسؤوليتك!",
+    "Cannot write into \"apps\" directory." : "لا يمكن الكتابة في الدليل \"apps\".",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "يمكن إصلاح ذلك عادةً عن طريق منح خادم الويب حق الكتابة في دليل التطبيقات في الملف او تعطيل متجر تطبيقات ابل في ملف \"config\".",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> تمّ تعيينه إلى <code>%s</code> بدلاً عن القيمة المتوقعة <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "لإصلاح هذا الخطأ، قم بتعيين<code>mbstring.func_overload</code> إلى <code>0</code> في php.ini."
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
