@@ -2,7 +2,7 @@ OC.L10N.register(
     "lib",
     {
     "Cannot write into \"config\" directory!" : "No faghet a iscriere in sa cartella \"config\"!",
-    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Ma si preferes allogare s'archìviu de letura isceti congi.php, imposta su sèberu \"config_is_read_only\"",
+    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Ma si preferis mantènnere s'archìviu config.php comente de letura isceti, cunfigura s'optzione \"config_is_read_only\" comente \"true\".",
     "See %s" : "Càstia %s",
     "Sample configuration detected" : "S'at agatadu una cunfiguratzione de esèmpiu",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Est istadu iscobertu ca sa cunfiguratzione de esèmpiu est istada copiada. Custu podet blocare s'installatzione e no est suportadu. Leghe sa documentatzione in config.php antis de fàghere càmbios.",
@@ -12,7 +12,6 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s e %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s e %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s e %5$s",
-    "Education Edition" : "Editzione didàtica",
     "Enterprise bundle" : "Pachete Enterprise",
     "Groupware bundle" : "Pachete Groupware",
     "Hub bundle" : "Pachete Hub",
@@ -46,6 +45,8 @@ OC.L10N.register(
     "Invalid image" : "Immàgine non bàlida",
     "Avatar image is not square" : "S'immàgine de s'avatar no est cuadrada",
     "Files" : "Archìvios",
+    "View profile" : "Ammustra su profilu",
+    "_%nh_::_%nh_" : ["%nh","%nh"],
     "today" : "oe",
     "tomorrow" : "cras",
     "yesterday" : "eris",
@@ -67,24 +68,23 @@ OC.L10N.register(
     "seconds ago" : "segundos a immoe",
     "Empty file" : "Archìviu bòidu",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Su mòdulu cun ID: %s no esistit. Ativa·ddu in sa cunfiguratzione de s'aplicatzione o cuntata s'amministratzione.",
+    "Dot files are not allowed" : "Is archìvios cun unu puntu a su cumintzu no sunt permìtidos",
     "File already exists" : "S'archìviu b'est giai",
     "Invalid path" : "Percursu non bàlidu",
     "Failed to create file from template" : "No at fatu a creare s'archìviu dae su modellu",
     "Templates" : "Modellos",
-    "File name is a reserved word" : "Su nùmene de s'archìviu est unu faeddu riservadu",
-    "File name contains at least one invalid character" : "Su nùmene de s'archìviu cuntenet a su mancu unu caràtere imbàlidu",
-    "File name is too long" : "Su nùmene de s'archìviu est tropu longu",
-    "Dot files are not allowed" : "Is archìvios cun unu puntu a su cumintzu no sunt permìtidos",
+    "Filename contains at least one invalid character" : "Su nùmene de su documentu cuntenet a su mancu unu caràtere non vàlidu",
     "Empty filename is not allowed" : "Unu nùmene de archìviu bòidu no est permìtidu",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "No faghet a installare s'aplicatzione \"%s\"  ca no faghet a lèghere s'archìviu appinfo.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "No faghet a installare s'aplicatzione \"%s\" ca no est cumpatìbile cun custa versione de su serbidore.",
     "__language_name__" : "sardu",
     "This is an automatically sent email, please do not reply." : "Custu est unu messàgiu de posta imbiadu in automàticu, non rispondas.",
+    "Help & privacy" : "Agiudu e riservadesa",
     "Appearance and accessibility" : "Aspetu e atzessibilidade",
     "Apps" : "Aplicatziones",
     "Settings" : "Cunfiguratzione",
     "Log out" : "Essi·nche",
-    "Users" : "Utentes",
+    "Accounts" : "Accounts",
     "Email" : "Posta eletrònica",
     "Phone" : "Telèfonu",
     "Twitter" : "Twitter",
@@ -94,38 +94,33 @@ OC.L10N.register(
     "About" : "In contu de",
     "Display name" : "Ammustra nùmene",
     "Headline" : "Tìtulos",
+    "Organization" : "Organizatzione",
     "Role" : "Faina",
     "Additional settings" : "Cunfiguratziones in agiunta",
     "You need to enter details of an existing account." : "Nche depes insertare is detàllios de unu contu chi b'est giai.",
     "Oracle connection could not be established" : "No at fatu a istabilire sa connessione Oracle",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X no est suportadu e %s no at a funtzionare in manera curreta in custa prataforma. Imprea•ddu a arriscu tuo!",
     "For the best results, please consider using a GNU/Linux server instead." : "Pro su mellus resurtadu, cunsidera in càmbiu de impreare unu serbidore GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Parit ca custa istàntzia %s est traballende in un'ambiente PHP a 32-bit e sa open_basedir est istada cunfigurada in php.ini. Custu at a causare problemas cun archìvios de prus de 4 GB e est iscussigiadu a forte.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Boga·nche sa cunfiguratzione open_basedir in su php.ini tuo o càmbia a su PHP a 64-bit.",
-    "Set an admin password." : "Imposta una crae pro chie amministrat.",
+    "Set an admin password." : "Cunfigura una crae de amministratzione.",
     "Cannot create or write into the data directory %s" : "No faghet a creare o a iscriere a intro de sa cartella de datos %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Su motore de cumpartzidura %s depet cumpletare s'interfache OCP\\Share_Backend",
     "Sharing backend %s not found" : "Motore de cumpartzidura%s no agatadu",
     "Sharing backend for %s not found" : "Motore de cumpartzidura pro %s no agatadu",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s at cumpartzidu »%2$s« cun tegus e bolet agiùnghere:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s at cumpartzidu »%2$s« cun tegus e bolet agiùnghere",
-    "»%s« added a note to a file shared with you" : "»%s« at agiuntu una nota a un'archìviu cumpartzidu cun tegus",
-    "Open »%s«" : "Aberi »%s«",
     "%1$s via %2$s" : "%1$s cun %2$s",
+    "Unknown share type" : "Genia de cumpartzidura disconnota",
+    "Shared path must be either a file or a folder" : "Su percursu cumpartzidu depet èssere un'archìviu o una cartella",
     "You are not allowed to share %s" : "No tenes su permissu de cumpartzire %s",
     "Cannot increase permissions of %s" : "No faghet a crèschere is permissos de %s",
     "Files cannot be shared with delete permissions" : "No faghet a cumpartzire archìvios cun permissos de cantzelladura",
     "Files cannot be shared with create permissions" : "No faghet a cumpartzire archìvios cun permissos de creatzione",
     "Expiration date is in the past" : "Sa data de iscadèntzia est giai passada",
-    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["No faghet a impostare sa data de iscadèntzia a prus de %n die in su benidore","No faghet a impostare sa data de iscadèntzia a prus de %n dies in su benidore"],
+    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["No faghet a impostare sa data de iscadèntzia a prus de %n die in su benidore","Impossìbile cunfigurare sa data de iscadèntzia a prus de %n dies in su benidore"],
     "Sharing is only allowed with group members" : "Sa cumpartzidura est permìtida isceti cun is partetzipantes de su grupu",
-    "%1$s shared »%2$s« with you" : "%1$s at cumpartzidu »%2$s cun tegus",
-    "%1$s shared »%2$s« with you." : "%1$s at cumpartzidu »%2$s cun tegus.",
-    "Click the button below to open it." : "Incarca su butone a suta pro dd'abèrrere.",
     "The requested share does not exist anymore" : "Sa cumpartzidura pedida no b'est prus",
     "Could not find category \"%s\"" : "No at fatu a agatare sa categoria \"%s\"",
     "Sunday" : "Domìnigu",
-    "Monday" : "Lunis",
+    "Monday" : "lunis",
     "Tuesday" : "Martis",
     "Wednesday" : "Mércuris",
     "Thursday" : "Giòbia",
@@ -172,22 +167,20 @@ OC.L10N.register(
     "A valid password must be provided" : "Depes frunire una crae bàlida",
     "Login canceled by app" : "Atzessu annulladu dae s'aplicatzione",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Non faghet a installare s'aplicatzione %1$s ca is dipendèntzias in fatu non sunt  satisfatos:%2$s",
-    "a safe home for all your data" : "unu logu siguru pro totu is datos tuos",
-    "File is currently busy, please try again later" : "Pro immoe s'archìviu est impreadu, torra a proare a coa",
+    "a safe home for all your data" : "unu logu seguru pro totu is datos tuos",
     "Application is not enabled" : "S'aplicatzione no est ativada",
     "Authentication error" : "Errore de autenticatzione",
     "Token expired. Please reload page." : "Token iscadidu. Torra a carrigare sa pàgina.",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Perunu driver de base de datos (sqlite, mysql, or postgresql) installadu.",
-    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ma si preferes allogare s'archìviu de letura isceti congi.php, imposta su sèberu \"config_is_read_only\" a \"true\". Càstia %s",
+    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ma si preferis mantènnere s'archìviu config.php comente de letura isceti, cunfigura s'optzione \"config_is_read_only\" comente \"true\". Càstia %s",
     "PHP module %s not installed." : "Su mòdulu PHP %s no est installadu.",
     "Please ask your server administrator to install the module." : "Pedi a s'amministratzione de serbidore de installare su mòdulu.",
     "PHP setting \"%s\" is not set to \"%s\"." : "Sa cunfiguratzione PHP %s no est a \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Assentende custa cunfiguratzione in php.ini at a torrare a fàghere traballare Nextcloud",
-    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Parit che PHP siat impostadu pro nde bogare is blocos de documentatzione in lìnia. Custu at a impedire s'atzessu a medas aplicatziones printzipales.",
+    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Paret che PHP siat cunfigurare pro nde bogare is blocos de documentatzione in lìnia. Custu at a impedire s'atzessu a medas aplicatziones printzipales.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Podet èssere causadu dae una memòria temporànea/atzeleradore cales Zend Opcache o eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Is mòdulos PHP sunt istados installados, ma sunt ancora elencados comente mancantes?",
     "Please ask your server administrator to restart the web server." : "Pedi a s'amministratzione de su serbidore de torrare a aviare su serbidore ìnternet.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Assegura•ti chi in sa cartella de datos de orìgine nche siat un'archìviu cun nùmene \".ocdata\".",
     "Action \"%s\" not supported or implemented." : "S'atzione \"%s\" no est suportada o cumpletada.",
     "Authentication failed, wrong token or provider ID given" : "No at fatu a fàghere s'autenticatzione, token o ID de su frunidore isballiados",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Mancant paràmetros pro pòdere cumpletare sa rechesta. Paràmetros mancantes: \"%s\"",
@@ -199,22 +192,18 @@ OC.L10N.register(
     "Storage connection error. %s" : "Errore de connessione a s'archiviatzione. %s",
     "Storage is temporarily not available" : "S'archiviatzione no est disponìbile pro immoe.",
     "Storage connection timeout. %s" : "Tempus de connessione a s'archiviatzione iscadidu. %s",
-    "Logged in user must be an admin or sub admin" : "S'utente devet essere de s'amministratzione o de sa suta-amministratzione ",
-    "Logged in user must be an admin" : "S'utente devet essere de s'amministratzione ",
-    "Help" : "Agiudu",
-    "Unknown user" : "Utèntzia disconnota",
-    "MySQL username and/or password not valid" : "Su nùmene utente e/o sa crae de MySQL no sunt bàlidos",
-    "Oracle username and/or password not valid" : "Su nùmene utente e/o sa crae de Oracle no sunt bàlidos",
-    "PostgreSQL username and/or password not valid" : "Su nùmene utente e/o sa crae de Postgre SQL no sunt bàlidos",
-    "Set an admin username." : "Imposta unu nùmene utente pro chie amministrat.",
-    "Sharing %s failed, because this item is already shared with user %s" : "No at fatu a cumpartzire %s, ca custu elementu est giai istadu cumpartzidu cun s'utente %s",
-    "The username is already being used" : "Su nùmene utente est giai impreadu",
-    "Could not create user" : "No at fatu a creare s'utente",
-    "A valid username must be provided" : "Depes frunire unu nùmene utente bàlidu",
-    "Username contains whitespace at the beginning or at the end" : "Su nùmene utente cuntenet ispàtzios bòidos a su cumintzu o a sa fine",
-    "Username must not consist of dots only" : "Su nùmene utente no depet tènnere isceti puntos",
-    "Username is invalid because files already exist for this user" : "Su nùmene utente no est bàlidu, ca is archìvios bi sunt giai pro cust'utèntzia",
-    "User disabled" : "Utèntzia disativada",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Càmbia is permissos a 0770 aici sa cartella no podet èssere in is elencos de àteras utèntzias."
+    "Images" : "Immàgines",
+    "Optical character recognition" : "Reconnoschimentu òticu de si caràteres",
+    "Chat" : "Tzarrada",
+    "Generate a headline" : "Gènera unu tìtulu",
+    "Generates a possible headline for a text." : "Gènerat unu tìtulu possìbile pro unu testu.",
+    "The original text to generate a headline for" : "Su testu originale pro su chi s'at a generare unu tìtulu",
+    "The generated headline" : "Su tìtulu generadu",
+    "Text" : "Testu",
+    "Summary" : "Resumu",
+    "Translate" : "Borta",
+    "Result" : "Resurtadu",
+    "Generate headline" : "Gènera unu tìtulu",
+    "Organisation" : "Organizatzione"
 },
 "nplurals=2; plural=(n != 1);");
